@@ -6,6 +6,9 @@ var searchData=
   ['aubio_5fbintomidi',['aubio_bintomidi',['../musicutils_8h.html#aa73e67530bdc66bfa08ee4f08e48c3fc',1,'musicutils.h']]],
   ['aubio_5fcleanup',['aubio_cleanup',['../musicutils_8h.html#a2b5d813f8d70b69add6f4811a68c9424',1,'musicutils.h']]],
   ['aubio_5fdb_5fspl',['aubio_db_spl',['../musicutils_8h.html#a3493315027a046c796045c3ef1bd2d75',1,'musicutils.h']]],
+  ['aubio_5fdct_5fdo',['aubio_dct_do',['../dct_8h.html#aa34059719b811308528fddf68e25ac81',1,'dct.h']]],
+  ['aubio_5fdct_5frdo',['aubio_dct_rdo',['../dct_8h.html#a92512b1226110ba73e209bce822e1718',1,'dct.h']]],
+  ['aubio_5fdct_5ft',['aubio_dct_t',['../dct_8h.html#a317db5113553cf26997f25c0c9c6b085',1,'dct.h']]],
   ['aubio_5ffft_5fdo',['aubio_fft_do',['../fft_8h.html#af2a5dcf62bbb1feb5774591c9f449155',1,'fft.h']]],
   ['aubio_5ffft_5fdo_5fcomplex',['aubio_fft_do_complex',['../fft_8h.html#ad25d21808e97f526a975d9ea0731c4ec',1,'fft.h']]],
   ['aubio_5ffft_5fget_5fimag',['aubio_fft_get_imag',['../fft_8h.html#ac2754200d4e3d9b2779c702ed796785a',1,'fft.h']]],
